Class: COFF::SCOFF_LineNumbers
- Defined in:
- lib/rmasm/bincoff.rb
Overview
/* 1 line number entry for every "breakpointable" source line in a section.
- Line numbers are grouped on a per function basis; first entry in a function
- grouping will have l_lnno = 0 and in place of physical address will be the
- symbol table index of the function name. */ pragma pack(push, 1)